@@ -1,8 +1,37 @@
+# Copyright 2020-     Robot Framework Foundation
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from enum import Enum, auto
-from typing import TypedDict
+
+from typing_extensions import TypedDict
+
+BoundingBox = TypedDict(
+    "BoundingBox",
+    {"x": float, "y": float, "width": float, "height": float},
+    total=False,
+)
+
+Coordinates = TypedDict("Coordinates", {"x": float, "y": float}, total=False)
+
+MouseOptionsDict = TypedDict(
+    "MouseOptionsDict", {"x": float, "y": float, "options": dict}, total=False
+)
+
+ViewportDimensions = TypedDict("ViewportDimensions", {"width": int, "height": int})
 
 
-class AlertAction(Enum):
+class DialogAction(Enum):
     accept = auto()
     dismiss = auto()
 
@@ -14,6 +43,11 @@ class CookieType(Enum):
     str = string
 
 
+CookieSameSite = Enum(
+    "CookieSameSite", {"Strict": "Strict", "Lax": "Lax", "None": "None"}
+)
+
+
 class RequestMethod(Enum):
     HEAD = auto()
     GET = auto()
@@ -68,11 +102,11 @@ class SupportedBrowsers(Enum):
 
 ColorScheme = Enum("ColorScheme", ["dark", "light", "no-preference"])
 
-ViewportDimensions = TypedDict("ViewportDimensions", {"width": int, "height": int})
 
-MouseOptionsDict = TypedDict(
-    "MouseOptionsDict", {"x": float, "y": float, "options": dict}, total=False
-)
+class ViewportFields(Enum):
+    width = auto()
+    height = auto()
+    ALL = auto()
 
 
 class BoundingBoxFields(Enum):
